@@ -294,9 +294,13 @@ func (r *DevWorkspaceReconciler) Reconcile(ctx context.Context, req ctrl.Request
 
 	// Add automount resources into devfile containers
 	if err := automount.ProvisionAutoMountResourcesInto(devfilePodAdditions, clusterAPI, workspace.Namespace); err != nil {
-		var fatalErr *automount.FatalError
-		if errors.As(err, &fatalErr) {
-			return r.failWorkspace(workspace, fmt.Sprintf("Failed to process automount resources: %s", err), metrics.ReasonBadRequest, reqLogger, &reconcileStatus)
+		var autoMountErr *automount.AutoMountError
+		if errors.As(err, &autoMountErr) {
+			if autoMountErr.IsFatal {
+				return r.failWorkspace(workspace, fmt.Sprintf("Failed to process automount resources: %s", err), metrics.ReasonBadRequest, reqLogger, &reconcileStatus)
+			}
+			reqLogger.Info(autoMountErr.Error())
+			return reconcile.Result{Requeue: true}, nil
 		} else {
 			return reconcile.Result{}, err
 		}
@@ -604,7 +608,9 @@ func (r *DevWorkspaceReconciler) removeStartedAtFromCluster(
 
 func (r *DevWorkspaceReconciler) getWorkspaceId(ctx context.Context, workspace *dw.DevWorkspace) (string, error) {
 	if idOverride := workspace.Annotations[constants.WorkspaceIdOverrideAnnotation]; idOverride != "" {
-		// TODO: Check overridden workspace ID's length (what should max be?)
+		if len(idOverride) > 25 {
+			return "", fmt.Errorf("maximum length for DevWorkspace ID override is 25 characters")
+		}
 		dwList := &dw.DevWorkspaceList{}
 		if err := r.Client.List(ctx, dwList, &client.ListOptions{Namespace: workspace.Namespace}); err != nil {
 			return "", fmt.Errorf("failed to check DevWorkspace ID override: %w", err)
