@@ -1,6 +1,6 @@
 #!/bin/bash
 #
-# Copyright (c) 2019-2021 Red Hat, Inc.
+# Copyright (c) 2019-2022 Red Hat, Inc.
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -47,12 +47,12 @@ Arguments:
       Controller (and webhook) image to use for the default deployment.
       Used only when '--use-defaults' is passed; otherwise, the value of
       the DWO_IMG environment variable is used. If unspecified, the default
-      value of 'quay.io/devfile/devworkspace-controller:v0.11.0' is used
+      value of 'quay.io/devfile/devworkspace-controller:v0.14.1' is used
   --project-clone-image
       Image to use for the project clone init container. Used only when
       '--use-defaults' is passed; otherwise, the value of the PROJECT_CLONE_IMG
       environment variable is used. If unspecifed, the default value of
-      'quay.io/devfile/project-clone:v0.11.0' is used.
+      'quay.io/devfile/project-clone:v0.14.1' is used.
   --split-yaml
       Parse output file combined.yaml into a yaml file for each record
       in combined yaml. Files are output to the 'objects' subdirectory
@@ -111,11 +111,11 @@ done
 if $USE_DEFAULT_ENV; then
   echo "Using defaults for environment variables"
   export NAMESPACE=devworkspace-controller
-  export DWO_IMG=${DEFAULT_DWO_IMG:-"quay.io/devfile/devworkspace-controller:v0.11.0"}
-  export PROJECT_CLONE_IMG=${PROJECT_CLONE_IMG:-"quay.io/devfile/project-clone:v0.11.0"}
+  export DWO_IMG=${DEFAULT_DWO_IMG:-"quay.io/devfile/devworkspace-controller:v0.14.1"}
+  export PROJECT_CLONE_IMG=${PROJECT_CLONE_IMG:-"quay.io/devfile/project-clone:v0.14.1"}
   export PULL_POLICY=Always
   export DEFAULT_ROUTING=basic
-  export DEVWORKSPACE_API_VERSION=089a48011460cbd9f06f200bad5452137a25f34b
+  export DEVWORKSPACE_API_VERSION=32cae1f8e42c22035138ef6ee93080bc47d751c6
   export ROUTING_SUFFIX='""'
   export FORCE_DEVWORKSPACE_CRDS_UPDATE=true
 fi
@@ -195,7 +195,8 @@ if $GEN_OLM; then
   TMPCSV="csv.tmp.yaml"
   yq -Y -s '
     .[0].spec.relatedImages =
-        [ .[1].spec.template.spec.containers[].env |
+        [ .[] | select(.kind == "Deployment") |
+          .spec.template.spec.containers[].env |
           select(length>0) |
           .[] |
           select(.name | test("RELATED_IMAGE.*")) |
@@ -205,7 +206,7 @@ if $GEN_OLM; then
           }
         ] | .[0]' \
     deploy/templates/components/csv/clusterserviceversion.yaml \
-    deploy/templates/components/manager/manager.yaml > "$TMPCSV"
+    deploy/deployment/openshift/combined.yaml > "$TMPCSV"
   mv $TMPCSV deploy/templates/components/csv/clusterserviceversion.yaml
 
   # It's needed to filter out the ServiceAccount object for OLM, as having a serviceaccount that matches the serviceaccount
