@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2019-2021 Red Hat, Inc.
+// Copyright (c) 2019-2022 Red Hat, Inc.
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
@@ -17,6 +17,6 @@ package constants
 
 const (
 	ProjectsRootEnvVar   = "PROJECTS_ROOT"
-	ProjectsSourceEnvVar = "PROJECTS_SOURCE"
+	ProjectsSourceEnvVar = "PROJECT_SOURCE"
 	ProjectsVolumeName   = "projects"
 )
