@@ -221,7 +221,7 @@ func resolveElementByKubernetesImport(
 	}
 
 	if !canImportDWT(tools.WorkspaceNamespace, &dwTemplate) {
-		return nil, fmt.Errorf("could not find DevWorkspaceTemplate")
+		return nil, fmt.Errorf("plugin for component %s not found", name)
 	}
 
 	return &dwTemplate.Spec, nil
@@ -248,7 +248,9 @@ func resolveElementById(
 	if err != nil {
 		return nil, fmt.Errorf("failed to parse registry URL for component %s: %w", name, err)
 	}
-	pluginURL.Path = path.Join(pluginURL.Path, id)
+
+	// convention: elements specified by id are served at <registryUrl>/devfiles/<id>
+	pluginURL.Path = path.Join(pluginURL.Path, "devfiles", id)
 
 	dwt, err := network.FetchDevWorkspaceTemplate(pluginURL.String(), tools.HttpClient)
 	if err != nil {
