@@ -19,6 +19,7 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"strings"
 
 	nsconfig "github.com/devfile/devworkspace-operator/pkg/provision/config"
 	"github.com/devfile/devworkspace-operator/pkg/provision/sync"
@@ -50,12 +51,16 @@ var containerFailureStateReasons = []string{
 	"RunContainerError",
 }
 
-var unrecoverablePodEventReasons = []string{
-	"FailedPostStartHook",
-	"FailedMount",
-	"FailedScheduling",
-	"FailedCreate",
-	"ReplicaSetCreateError",
+// unrecoverablePodEventReasons contains Kubernetes events that should fail workspace startup
+// if they occur related to a workspace pod. Events are stored as a map with event names as keys
+// and values representing the threshold of how many times we can see an event before it is considered
+// unrecoverable.
+var unrecoverablePodEventReasons = map[string]int32{
+	"FailedPostStartHook":   1,
+	"FailedMount":           3,
+	"FailedScheduling":      1,
+	"FailedCreate":          1,
+	"ReplicaSetCreateError": 1,
 }
 
 var unrecoverableDeploymentConditionReasons = []string{
@@ -94,6 +99,10 @@ func SyncDeploymentToCluster(
 			},
 		}
 	}
+	if len(specDeployment.Spec.Template.Spec.Containers) == 0 {
+		// DevWorkspace defines no container components, cannot create a deployment
+		return DeploymentProvisioningStatus{ProvisioningStatus{Continue: true}}
+	}
 
 	clusterObj, err := sync.SyncObjectWithCluster(specDeployment, clusterAPI)
 	switch t := err.(type) {
@@ -230,14 +239,18 @@ func getSpecDeployment(
 		podAdditions.InitContainers[idx].VolumeMounts = append(podAdditions.InitContainers[idx].VolumeMounts, podAdditions.VolumeMounts...)
 	}
 
+	labels := map[string]string{}
+	labels[constants.DevWorkspaceIDLabel] = workspace.Status.DevWorkspaceId
+	labels[constants.DevWorkspaceNameLabel] = workspace.Name
+
+	annotations, err := getAdditionalAnnotations(workspace)
+
 	deployment := &appsv1.Deployment{
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      common.DeploymentName(workspace.Status.DevWorkspaceId),
-			Namespace: workspace.Namespace,
-			Labels: map[string]string{
-				constants.DevWorkspaceIDLabel:   workspace.Status.DevWorkspaceId,
-				constants.DevWorkspaceNameLabel: workspace.Name,
-			},
+			Name:        common.DeploymentName(workspace.Status.DevWorkspaceId),
+			Namespace:   workspace.Namespace,
+			Labels:      labels,
+			Annotations: annotations,
 		},
 		Spec: appsv1.DeploymentSpec{
 			Replicas: &replicas,
@@ -279,19 +292,25 @@ func getSpecDeployment(
 	if nodeSelector != nil && len(nodeSelector) > 0 {
 		deployment.Spec.Template.Spec.NodeSelector = nodeSelector
 	}
+	if workspace.Spec.Template.Attributes.Exists(constants.RuntimeClassNameAttribute) {
+		runtimeClassName := workspace.Spec.Template.Attributes.GetString(constants.RuntimeClassNameAttribute, nil)
+		if runtimeClassName != "" {
+			deployment.Spec.Template.Spec.RuntimeClassName = &runtimeClassName
+		}
+	}
 
-	if needsPVCWorkaround(podAdditions) {
+	if needPVC, pvcName := needsPVCWorkaround(podAdditions); needPVC {
 		// Kubernetes creates directories in a PVC to support subpaths such that only the leaf directory has g+rwx permissions.
 		// This means that mounting the subpath e.g. <workspace-id>/plugins will result in the <workspace-id> directory being
 		// created with 755 permissions, requiring the root UID to remove it.
 		// To avoid this issue, we need to ensure that the first volumeMount encountered is for the <workspace-id> subpath.
 		if len(deployment.Spec.Template.Spec.InitContainers) > 0 {
 			volumeMounts := deployment.Spec.Template.Spec.InitContainers[0].VolumeMounts
-			volumeMounts = append([]corev1.VolumeMount{getWorkspaceSubpathVolumeMount(workspace.Status.DevWorkspaceId)}, volumeMounts...)
+			volumeMounts = append([]corev1.VolumeMount{getWorkspaceSubpathVolumeMount(workspace.Status.DevWorkspaceId, pvcName)}, volumeMounts...)
 			deployment.Spec.Template.Spec.InitContainers[0].VolumeMounts = volumeMounts
 		} else {
 			volumeMounts := deployment.Spec.Template.Spec.Containers[0].VolumeMounts
-			volumeMounts = append([]corev1.VolumeMount{getWorkspaceSubpathVolumeMount(workspace.Status.DevWorkspaceId)}, volumeMounts...)
+			volumeMounts = append([]corev1.VolumeMount{getWorkspaceSubpathVolumeMount(workspace.Status.DevWorkspaceId, pvcName)}, volumeMounts...)
 			deployment.Spec.Template.Spec.Containers[0].VolumeMounts = volumeMounts
 		}
 	}
@@ -351,7 +370,7 @@ func checkPodsState(workspace *dw.DevWorkspace,
 				return fmt.Sprintf("Init Container %s has state %s", initContainerStatus.Name, initContainerStatus.State.Waiting.Reason), nil
 			}
 		}
-		if msg, err := checkPodEvents(&pod, clusterAPI); err != nil || msg != "" {
+		if msg, err := checkPodEvents(&pod, workspace.Status.DevWorkspaceId, clusterAPI); err != nil || msg != "" {
 			return msg, err
 		}
 	}
@@ -417,11 +436,9 @@ func mergePodAdditions(toMerge []v1alpha1.PodAdditions) (*v1alpha1.PodAdditions,
 	return podAdditions, nil
 }
 
-func getWorkspaceSubpathVolumeMount(workspaceId string) corev1.VolumeMount {
-	volumeName := config.Workspace.PVCName
-
+func getWorkspaceSubpathVolumeMount(workspaceId, pvcName string) corev1.VolumeMount {
 	workspaceVolumeMount := corev1.VolumeMount{
-		Name:      volumeName,
+		Name:      pvcName,
 		MountPath: "/tmp/workspace-storage",
 		SubPath:   workspaceId,
 	}
@@ -429,17 +446,38 @@ func getWorkspaceSubpathVolumeMount(workspaceId string) corev1.VolumeMount {
 	return workspaceVolumeMount
 }
 
-func needsPVCWorkaround(podAdditions *v1alpha1.PodAdditions) bool {
+func needsPVCWorkaround(podAdditions *v1alpha1.PodAdditions) (needs bool, pvcName string) {
 	commonPVCName := config.Workspace.PVCName
 	for _, vol := range podAdditions.Volumes {
 		if vol.Name == commonPVCName {
-			return true
+			return true, commonPVCName
+		}
+		if vol.Name == constants.CheCommonPVCName {
+			return true, constants.CheCommonPVCName
 		}
 	}
-	return false
+	return false, ""
 }
 
-func checkPodEvents(pod *corev1.Pod, clusterAPI sync.ClusterAPI) (msg string, err error) {
+func getAdditionalAnnotations(workspace *dw.DevWorkspace) (map[string]string, error) {
+	annotations := map[string]string{}
+
+	for _, component := range workspace.Spec.Template.Components {
+		if component.Container == nil || component.Container.Annotation == nil || component.Container.Annotation.Deployment == nil {
+			continue
+		}
+		for k, v := range component.Container.Annotation.Deployment {
+			if currValue, exists := annotations[k]; exists && v != currValue {
+				return nil, fmt.Errorf("conflicting annotations found on container components for key %s", k)
+			}
+			annotations[k] = v
+		}
+	}
+
+	return annotations, nil
+}
+
+func checkPodEvents(pod *corev1.Pod, workspaceID string, clusterAPI sync.ClusterAPI) (msg string, err error) {
 	evs := &corev1.EventList{}
 	selector, err := fields.ParseSelector(fmt.Sprintf("involvedObject.name=%s", pod.Name))
 	if err != nil {
@@ -452,9 +490,24 @@ func checkPodEvents(pod *corev1.Pod, clusterAPI sync.ClusterAPI) (msg string, er
 		if ev.InvolvedObject.Kind != "Pod" {
 			continue
 		}
-		for _, fatalEv := range unrecoverablePodEventReasons {
-			if ev.Reason == fatalEv && !checkIfUnrecoverableEventIgnored(ev.Reason) {
-				return fmt.Sprintf("Detected unrecoverable event %s: %s", ev.Reason, ev.Message), nil
+
+		// On OpenShift, it's possible see "FailedMount" events when using a routingClass that depends on the service-ca
+		// operator. To avoid this, we always ignore FailedMount events if the message refers to the DWO-provisioned volume
+		if infrastructure.IsOpenShift() &&
+			ev.Reason == "FailedMount" &&
+			strings.Contains(ev.Message, common.ServingCertVolumeName(common.ServiceName(workspaceID))) {
+			continue
+		}
+
+		if maxCount, isUnrecoverableEvent := unrecoverablePodEventReasons[ev.Reason]; isUnrecoverableEvent {
+			if !checkIfUnrecoverableEventIgnored(ev.Reason) && ev.Count >= maxCount {
+				var msg string
+				if ev.Count > 1 {
+					msg = fmt.Sprintf("Detected unrecoverable event %s %d times: %s", ev.Reason, ev.Count, ev.Message)
+				} else {
+					msg = fmt.Sprintf("Detected unrecoverable event %s: %s", ev.Reason, ev.Message)
+				}
+				return msg, nil
 			}
 		}
 	}
