@@ -96,7 +96,7 @@ func SetupRemotes(repo *git.Repository, project *dw.Project, projectPath string)
 // CheckoutReference sets the current HEAD in repo to point at the revision and remote referenced by checkoutFrom
 func CheckoutReference(repo *git.Repository, project *dw.Project, projectPath string) error {
 	checkoutFrom := project.Git.CheckoutFrom
-	if checkoutFrom == nil {
+	if checkoutFrom == nil || checkoutFrom.Revision == "" {
 		return nil
 	}
 	var defaultRemoteName string
@@ -118,6 +118,11 @@ func CheckoutReference(repo *git.Repository, project *dw.Project, projectPath st
 		return fmt.Errorf("failed to read remote %s: %s", defaultRemoteName, err)
 	}
 
+	branch, err := repo.Branch(checkoutFrom.Revision)
+	if err == nil {
+		return checkoutLocalBranch(projectPath, branch.Name, defaultRemoteName)
+	}
+
 	for _, ref := range refs {
 		if ref.Name().Short() != checkoutFrom.Revision {
 			continue
@@ -130,10 +135,25 @@ func CheckoutReference(repo *git.Repository, project *dw.Project, projectPath st
 	}
 
 	log.Printf("No tag or branch named %s found on remote %s; attempting to resolve commit", checkoutFrom.Revision, defaultRemoteName)
-	if _, err := repo.ResolveRevision(plumbing.Revision(checkoutFrom.Revision)); err != nil {
-		return fmt.Errorf("failed to resolve commit %s: %s", checkoutFrom.Revision, err)
+	if _, err := repo.ResolveRevision(plumbing.Revision(checkoutFrom.Revision)); err == nil {
+		return checkoutCommit(projectPath, checkoutFrom.Revision)
 	}
-	return checkoutCommit(projectPath, checkoutFrom.Revision)
+	log.Printf("Could not find revision %s in repository, using default branch", checkoutFrom.Revision)
+	return nil
+}
+
+func checkoutLocalBranch(projectPath, branchName, remote string) error {
+	log.Printf("Checking out local branch %s", branchName)
+	if err := shell.GitCheckoutBranchLocal(projectPath, branchName); err != nil {
+		return fmt.Errorf("failed to checkout branch %s: %s", branchName, err)
+	}
+
+	log.Printf("Setting tracking remote for branch %s to %s", branchName, remote)
+	if err := shell.GitSetTrackingRemoteBranch(projectPath, branchName, remote); err != nil {
+		return fmt.Errorf("failed to set tracking for branch %s: %w", branchName, err)
+	}
+
+	return nil
 }
 
 func checkoutRemoteBranch(projectPath string, remote string, branchRef *plumbing.Reference) error {
